#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.component.association.interfaces import IAssociationInfo
from pyams_content.features.renderer.interfaces import IContentRenderer
from pyams_content.shared.imagemap.interfaces import IWfImageMap, IImageMapParagraph
from pyams_skin.layer import IPyAMSLayer

# import packages
from pyams_content.features.renderer.skin import BaseContentRenderer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config

from pyams_default_theme import _


#
# Imagemap renderer
#

@adapter_config(name='imagemap-render', context=(IWfImageMap, IPyAMSLayer), provides=IContentRenderer)
@template_config(template='templates/render.pt', layer=IPyAMSLayer)
class ImagemapRenderer(BaseContentRenderer):
    """Image map renderer"""

    weight = 20

    def get_item_info(self, item):
        return IAssociationInfo(item, None)


#
# Imagemap paragraph renderer
#

@adapter_config(name='default', context=(IImageMapParagraph, IPyAMSLayer), provides=IContentRenderer)
@template_config(template='templates/imagemap-default.pt', layer=IPyAMSLayer)
class ImagemapDefaultParagraphRenderer(BaseContentRenderer):
    """Image map default paragraph renderer"""

    label = _("Default imagemap renderer")

    i18n_context_attrs = ('title', )

    def get_item_info(self, item):
        return IAssociationInfo(item, None)
